@@ -1,8 +1,10 @@
 import os
+import re
 import zipfile
 from enum import Enum
 from typing import IO, Optional
 
+from unstructured.nlp.patterns import LIST_OF_DICTS_PATTERN
 from unstructured.partition.common import exactly_one
 
 try:
@@ -23,6 +25,10 @@ DOC_MIME_TYPES = [
     "application/msword",
 ]
 
+ODT_MIME_TYPES = [
+    "application/vnd.oasis.opendocument.text",
+]
+
 XLSX_MIME_TYPES = [
     "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
 ]
@@ -112,6 +118,9 @@ class FileType(Enum):
     # Compressed Types
     ZIP = 60
 
+    # Open Office Types
+    ODT = 70
+
     # NOTE(robinson) - This is to support sorting for pandas groupby functions
     def __lt__(self, other):
         return self.name < other.name
@@ -133,6 +142,7 @@ STR_TO_FILETYPE = {
     "application/vnd.openxmlformats-officedocument.presentationml.presentation": FileType.PPTX,
     "application/vnd.ms-powerpoint": FileType.PPT,
     "application/xml": FileType.XML,
+    "application/vnd.oasis.opendocument.text": FileType.ODT,
 }
 
 
@@ -158,6 +168,7 @@ EXT_TO_FILETYPE = {
     ".json": FileType.JSON,
     ".epub": FileType.EPUB,
     ".msg": FileType.MSG,
+    ".odt": FileType.ODT,
     None: FileType.UNK,
 }
 
@@ -169,7 +180,8 @@ def detect_filetype(
     file_filename: Optional[str] = None,
 ) -> Optional[FileType]:
     """Use libmagic to determine a file's type. Helps determine which partition brick
-    to use for a given file. A return value of None indicates a non-supported file type."""
+    to use for a given file. A return value of None indicates a non-supported file type.
+    """
     exactly_one(filename=filename, file=file)
 
     if content_type:
@@ -218,6 +230,9 @@ def detect_filetype(
     elif mime_type in DOC_MIME_TYPES:
         return FileType.DOC
 
+    elif mime_type in ODT_MIME_TYPES:
+        return FileType.ODT
+
     elif mime_type in MSG_MIME_TYPES:
         return FileType.MSG
 
@@ -239,18 +254,6 @@ def detect_filetype(
     elif mime_type.endswith("rtf"):
         return FileType.RTF
 
-    elif mime_type in TXT_MIME_TYPES:
-        if extension and extension == ".eml":
-            return FileType.EML
-        elif extension and extension == ".md":
-            return FileType.MD
-        elif extension and extension == ".rtf":
-            return FileType.RTF
-
-        if file and not extension and _check_eml_from_buffer(file=file) is True:
-            return FileType.EML
-        return FileType.TXT
-
     elif mime_type.endswith("xml"):
         if extension and extension == ".html":
             return FileType.HTML
@@ -260,7 +263,19 @@ def detect_filetype(
     elif mime_type == "text/html":
         return FileType.HTML
 
-    elif mime_type.startswith("text"):
+    elif mime_type in TXT_MIME_TYPES or mime_type.startswith("text"):
+        if extension and extension == ".eml":
+            return FileType.EML
+        elif extension and extension == ".md":
+            return FileType.MD
+        elif extension and extension == ".rtf":
+            return FileType.RTF
+
+        if _is_text_file_a_json(file=file, filename=filename):
+            return FileType.JSON
+
+        if file and not extension and _check_eml_from_buffer(file=file) is True:
+            return FileType.EML
         return FileType.TXT
 
     elif mime_type in XLSX_MIME_TYPES:
@@ -310,24 +325,49 @@ def _detect_filetype_from_octet_stream(file: IO) -> FileType:
         archive = zipfile.ZipFile(file)
 
         archive_filenames = [f.filename for f in archive.filelist]
-        if all([f in archive_filenames for f in EXPECTED_DOCX_FILES]):
+        if all(f in archive_filenames for f in EXPECTED_DOCX_FILES):
             return FileType.DOCX
-        elif all([f in archive_filenames for f in EXPECTED_XLSX_FILES]):
+        elif all(f in archive_filenames for f in EXPECTED_XLSX_FILES):
             return FileType.XLSX
-        elif all([f in archive_filenames for f in EXPECTED_PPTX_FILES]):
+        elif all(f in archive_filenames for f in EXPECTED_PPTX_FILES):
             return FileType.PPTX
 
-    logger.warning("Could not detect the filetype from application/octet-stream MIME type.")
+    logger.warning(
+        "Could not detect the filetype from application/octet-stream MIME type.",
+    )
     return FileType.UNK
 
 
+def _is_text_file_a_json(
+    filename: Optional[str] = None,
+    content_type: Optional[str] = None,
+    file: Optional[IO] = None,
+):
+    """Detects if a file that has a text/plain MIME type is a JSON file."""
+    exactly_one(filename=filename, file=file)
+
+    if file is not None:
+        file.seek(0)
+        file_content = file.read(4096)
+        if isinstance(file_content, str):
+            file_text = file_content
+        else:
+            file_text = file_content.decode(errors="ignore")
+        file.seek(0)
+    elif filename is not None:
+        with open(filename) as f:
+            file_text = f.read()
+
+    return re.match(LIST_OF_DICTS_PATTERN, file_text) is not None
+
+
 def _check_eml_from_buffer(file: IO) -> bool:
     """Checks if a text/plain file is actually a .eml file. Uses a regex pattern to see if the
     start of the file matches the typical pattern for a .eml file."""
     file.seek(0)
     file_content = file.read(4096)
     if isinstance(file_content, bytes):
-        file_head = file_content.decode("utf-8")
+        file_head = file_content.decode("utf-8", errors="ignore")
     else:
         file_head = file_content
 
