@@ -1,5 +1,7 @@
 import subprocess
-from typing import List, Optional, Tuple, Union
+from io import BytesIO
+from tempfile import SpooledTemporaryFile
+from typing import BinaryIO, List, Optional, Tuple, Union
 
 from unstructured.documents.elements import (
     TYPE_TO_TEXT_ELEMENT_MAP,
@@ -90,7 +92,16 @@ def add_element_metadata(
     page_number: int = 1
     for layout_element in layout_elements:
         element = normalize_layout_element(layout_element)
-        metadata = ElementMetadata(filename=filename, url=url, page_number=page_number)
+        if hasattr(layout_element, "text_as_html"):
+            text_as_html: Optional[str] = layout_element.text_as_html
+        else:
+            text_as_html = None
+        metadata = ElementMetadata(
+            filename=filename,
+            url=url,
+            page_number=page_number,
+            text_as_html=text_as_html,
+        )
         if isinstance(element, list):
             for _element in element:
                 _element.metadata = metadata
@@ -148,3 +159,15 @@ def exactly_one(**kwargs) -> None:
         else:
             message = f"{names[0]} must be specified."
         raise ValueError(message)
+
+
+def spooled_to_bytes_io_if_needed(
+    file_obj: Optional[Union[bytes, BinaryIO, SpooledTemporaryFile]],
+) -> Optional[Union[bytes, BinaryIO]]:
+    if isinstance(file_obj, SpooledTemporaryFile):
+        file_obj.seek(0)
+        contents = file_obj.read()
+        return BytesIO(contents)
+    else:
+        # Return the original file object if it's not a SpooledTemporaryFile
+        return file_obj
