@@ -1,8 +1,7 @@
 from typing import IO, List, Optional
 
 from unstructured.documents.elements import Element
-from unstructured.file_utils.file_conversion import convert_epub_to_html
-from unstructured.partition.html import partition_html
+from unstructured.partition.html import convert_and_partition_html
 
 
 def partition_epub(
@@ -15,18 +14,16 @@ def partition_epub(
 
     Parameters
     ----------
-     filename
+    filename
         A string defining the target filename path.
     file
         A file-like object using "rb" mode --> open(filename, "rb").
     include_page_breaks
         If True, the output will include page breaks if the filetype supports it
     """
-    html_text = convert_epub_to_html(filename=filename, file=file)
-    # NOTE(robinson) - pypandoc returns a text string with unicode encoding
-    # ref: https://github.com/JessicaTegner/pypandoc#usage
-    return partition_html(
-        text=html_text,
+    return convert_and_partition_html(
+        source_format="epub",
+        filename=filename,
+        file=file,
         include_page_breaks=include_page_breaks,
-        encoding="unicode",
     )
