@@ -1,6 +1,7 @@
 from typing import List, Optional
 
 from unstructured.documents.elements import Element
+from unstructured.partition.common import exactly_one
 from unstructured.partition.pdf import partition_pdf_or_image
 
 
@@ -11,8 +12,11 @@ def partition_image(
     template: Optional[str] = None,
     token: Optional[str] = None,
     include_page_breaks: bool = False,
+    ocr_languages: str = "eng",
+    strategy: str = "auto",
 ) -> List[Element]:
     """Parses an image into a list of interpreted elements.
+
     Parameters
     ----------
     filename
@@ -27,9 +31,20 @@ def partition_image(
         be used.
     token
         A string defining the authentication token for a self-host url, if applicable.
+    ocr_languages
+        The languages to use for the Tesseract agent. To use a language, you'll first need
+        to install the appropriate Tesseract language pack.
+    strategy
+        The strategy to use for partitioning the PDF. Valid strategies are "hi_res" and
+        "ocr_only". When using the "hi_res" strategy, the function uses a layout detection
+        model if to identify document elements. When using the "ocr_only" strategy,
+        partition_image simply extracts the text from the document using OCR and processes it.
     """
+    exactly_one(filename=filename, file=file)
+
     if template is None:
         template = "layout/image"
+
     return partition_pdf_or_image(
         filename=filename,
         file=file,
@@ -37,4 +52,6 @@ def partition_image(
         template=template,
         token=token,
         include_page_breaks=include_page_breaks,
+        ocr_languages=ocr_languages,
+        strategy=strategy,
     )
